const CACHE_NAME = 'sakuraidc-cache-v1';
const FILE_TYPES_TO_CACHE = ['.html', '.css', '.js', '.png', '.jpg', '.jpeg', '.gif', '.svg', '.webp','.mp4','.mp3'];

self.addEventListener('install', function(event) {
  // Skip waiting to activate the new service worker immediately
  self.skipWaiting();
});

self.addEventListener('fetch', function(event) {
  if (shouldCache(event.request.url)) {
    event.respondWith(
      caches.match(event.request).then(function(response) {
        if (response) {
          return response;
        }
        return fetch(event.request).then(function(response) {
          if (!response || response.status !== 200 || response.type !== 'basic') {
            return response;
          }
          const responseToCache = response.clone();
          caches.open(CACHE_NAME).then(function(cache) {
            const headers = new Headers(responseToCache.headers);
            headers.append('Cache-Control', 'public, max-age=31536000');
            cache.put(event.request, new Response(responseToCache.body, {
              status: responseToCache.status,
              statusText: responseToCache.statusText,
              headers: headers
            }));
          });
          return response;
        });
      })
    );
  } else {
    event.respondWith(fetch(event.request));
  }
});

self.addEventListener('activate', function(event) {
  const cacheWhitelist = [CACHE_NAME];
  event.waitUntil(
    caches.keys().then(function(cacheNames) {
      return Promise.all(
        cacheNames.map(function(cacheName) {
          if (cacheWhitelist.indexOf(cacheName) === -1) {
            return caches.delete(cacheName);
          }
        })
      );
    })
  );
});

function shouldCache(url) {
  return FILE_TYPES_TO_CACHE.some(type => url.endsWith(type));
}
